# MD026 - No Trailing Punctuation in Headings

## Description

This rule ensures that headings do not end with inappropriate punctuation characters. Trailing punctuation in headings can be visually distracting and is generally considered poor style in technical documentation.

By default, this rule checks for the following punctuation characters: `.,;`. The rule is designed to be lenient and allows legitimate punctuation usage such as:

- **Colons in categorical headings**: "FAQ: Frequently Asked Questions", "API: Methods", "Step 1: Setup"
- **Question marks in question headings**: "What is Markdown?", "How does it work?"
- **Exclamation marks for emphasis**: "Important!", "New!", "Warning!"

The list of punctuation characters can be customized through configuration. When custom punctuation is specified, the lenient behavior is disabled and all instances of the specified punctuation are flagged.

## Examples

### Valid

```markdown
# Introduction

## FAQ: Frequently Asked Questions

### What is Markdown?

#### Important!

##### Step 1: Setup
```

### Invalid

<!-- rumdl-disable MD026 -->

```markdown
# This is a sentence.

## Random heading;

### This seems wrong,
```

<!-- rumdl-enable MD026 -->

### Fixed

```markdown
# This is a sentence

## Random heading

### This seems wrong
```

## Configuration

This rule has the following configuration options:

- `punctuation`: A string containing the punctuation characters to check for at the end of headings. Default is `.,;` (more restrictive than before). When using the default setting, the rule applies intelligent exceptions for legitimate punctuation usage. When custom punctuation is specified, all instances are flagged without exceptions.

## Special Cases

- This rule does not apply to headings within code blocks
- **Intelligent punctuation detection**: When using the default punctuation setting, the rule allows legitimate uses such as:
  - Colons in categorical headings: "FAQ:", "API:", "Step 1:", "Version 2.0:", "Chapter 1:", "Error:", "Note:", etc.
  - Question marks in question headings: "What...", "How...", "Why...", "When...", "Where...", "Who...", "Which...", "Can...", "Should...", etc.
  - Exclamation marks for emphasis: "Important!", "New!", "Warning!", "Alert!", "Notice!", "Attention!"
- Punctuation characters that are part of a word (like in "Node.js") are not affected by this rule
- The rule does not affect punctuation in the middle of a heading
- When custom punctuation is configured, the intelligent detection is disabled and all instances are flagged

## Related Rules

- [MD001 - Heading increment](md001.md): Ensures heading levels increment by one level at a time
- [MD003 - Heading style](md003.md): Ensures consistent heading style
- [MD025 - Single title/h1](md025.md): Ensures there's only one top-level heading
