# MD036 - No Emphasis as Heading

## Description

This rule ensures that emphasis (bold or italic) is not used as a substitute for proper headings.
Using emphasis to create headings can lead to inconsistent document structure and accessibility issues.

Proper headings provide better document structure, are more accessible, and enable automatic
generation of tables of contents.

<!-- rumdl-disable MD036 -->

## Examples

### Valid

```markdown
# This is a proper heading

## This is another proper heading

This is a paragraph with **bold** and *italic* text within it.

**Table of Contents**

*Contents*

__TOC__

_Index_
```

### Invalid

```markdown
**This is not a proper heading**

*This is not a proper heading either*

***This is definitely not a proper heading***
```

### Fixed

```markdown
## This is not a proper heading

## This is not a proper heading either

### This is definitely not a proper heading
```

### Punctuation Removal

When converting emphasis to headings, trailing punctuation is automatically removed:

```markdown
**Example output:**
*Configuration:*
**Title with period.**
```

Becomes:

```markdown
## Example output
# Configuration
## Title with period
```

<!-- rumdl-enable MD036 -->

## Configuration

This rule supports the following configuration option:

- `punctuation` (string, default: `".,;:!?"`): Punctuation characters to remove from the end of headings when converting from emphasis
  - Set to a string of characters to remove those specific punctuation marks
  - Set to empty string (`""`) to preserve all punctuation
  - Default removes common trailing punctuation: period, comma, semicolon, colon, exclamation mark, question mark

### Example Configuration

```toml
[MD036]
punctuation = ""  # Preserve all punctuation in headings

# Or specify custom punctuation to remove
[MD036]
punctuation = ".!?"  # Only remove periods, exclamation marks, and question marks
```

## Special Cases

- This rule only applies to emphasis that appears alone on a line
- Emphasis within other content is not affected
- Both single emphasis (*italic*) and double emphasis (**bold**) are checked
- Triple emphasis (***bold italic***) is also checked
- Trailing punctuation (`.`, `:`, `;`, `!`, `?`) is automatically removed when converting to headings
- Common Table of Contents labels are excluded and will not be flagged:
  - `**Table of Contents**`, `*Contents*`, `__TOC__`, `_Index_`
  - These are considered legitimate uses of emphasis for document structure

## Related Rules

- [MD001 - Heading increment](md001.md): Ensures heading levels increment by one level at a time
- [MD003 - Heading style](md003.md): Ensures consistent heading style
- [MD018 - No missing space in ATX heading](md018.md): Ensures proper spacing in headings
